Error

Enum Error 

pub enum Error {
Show 24 variants CurrentDir { source: Error, }, NormalizePath { path: PathBuf, source: Error, }, NotGitWorktree, GitIo { command: String, source: Error, }, GitFailed { command: String, stderr: String, }, RootPathNotFound, ConfigNotFound(PathBuf), ConfigIo { path: PathBuf, source: Error, }, ConfigParse { path: PathBuf, message: String, }, ConfigInvalid { path: PathBuf, message: String, }, InvalidBooleanEnv { name: &'static str, value: String, }, NoConfigDetectedStrict, RootWorktreeStrict, CommandIo { label: String, source: Error, }, CommandFailed { label: String, status: ExitStatus, }, FileOperationConflict { operation: &'static str, path: PathBuf, message: String, }, FileOperationInvalid { operation: &'static str, message: String, }, FileOperationIo { operation: &'static str, path: PathBuf, source: Error, }, ScriptIo { path: PathBuf, source: Error, }, ScriptFailed { path: PathBuf, status: ExitStatus, }, Output { source: Error, }, DoctorFailed, InitTargetExists(PathBuf), InitIo { path: PathBuf, source: Error, },
}
Error type for treeboot-core operations.

Variants



CurrentDir

The current working directory could not be read.

Fields

source: Error

Source I/O error.



NormalizePath

A filesystem path could not be normalized.

Fields

path: PathBuf

Path that failed normalization.

source: Error

Source I/O error.



NotGitWorktree

The command was not run from a Git worktree.



GitIo

A Git command could not be spawned.

Fields

command: String

Human-readable command label.

source: Error

Source I/O error.



GitFailed

A Git command exited unsuccessfully.

Fields

command: String

Human-readable command label.

stderr: String

Standard error from Git.



RootPathNotFound

No root checkout path could be determined.



ConfigNotFound(PathBuf)

A specifically requested config file does not exist.



ConfigIo

A config file could not be read.

Fields

path: PathBuf

Config file path.

source: Error

Source I/O error.



ConfigParse

A config file contains invalid TOML.

Fields

path: PathBuf

Config file path.

message: String

Parse error message.



ConfigInvalid

A config file contains unsupported or invalid declarations.

Fields

path: PathBuf

Config file path.

message: String

Validation error message.



InvalidBooleanEnv

A treeboot boolean environment variable has an unsupported value.

Fields

name: &'static str

Environment variable name.

value: String

Environment variable value.



NoConfigDetectedStrict

No config was found while strict mode was enabled.



RootWorktreeStrict

The command was run from the root checkout while strict mode was enabled.



CommandIo

A configured command could not be spawned.

Fields

label: String

Human-readable command label.

source: Error

Source I/O error.



CommandFailed

A configured command exited unsuccessfully.

Fields

label: String

Human-readable command label.

status: ExitStatus

Process exit status.



FileOperationConflict

A file operation encountered an unsupported conflict.

Fields

operation: &'static str

Operation being applied.

path: PathBuf

Path involved in the conflict.

message: String

Human-readable conflict detail.



FileOperationInvalid

A manual file operation request is invalid.

Fields

operation: &'static str

Operation being planned.

message: String

Human-readable validation detail.



FileOperationIo

A file operation failed while accessing the filesystem.

Fields

operation: &'static str

Operation being applied.

path: PathBuf

Path being accessed.

source: Error

Source I/O error.



ScriptIo

An init script could not be spawned.

Fields

path: PathBuf

Script path.

source: Error

Source I/O error.



ScriptFailed

An init script exited unsuccessfully.

Fields

path: PathBuf

Script path.

status: ExitStatus

Script process status.



Output

Writing output failed.

Fields

source: Error

Source I/O error.



DoctorFailed

Doctor diagnostics found fatal issues.



InitTargetExists(PathBuf)

treeboot init refused to replace an existing target.



InitIo

An init file could not be written.

Fields

path: PathBuf

Init target path.

source: Error

Source I/O error.

Implementations

Source

impl Error

pub const fn exit_code(&self) -> u8

Returns the CLI exit code associated with this error.