OutputEvent

Enum OutputEvent 

pub enum OutputEvent {
Show 25 variants IgnoredInitScript { path: PathBuf, }, WouldRunInitScript { path: PathBuf, root_path: PathBuf, }, RunInitScript { path: PathBuf, }, NoConfigDetected, RootWorktreeDetected, ConfigDetected { path: PathBuf, }, FileOperationPlanningStarted { operation: FileOperationKind, source: PathBuf, target: PathBuf, }, FileOperationPlanningFinished { operation: FileOperationKind, source: PathBuf, target: PathBuf, action_count: usize, }, FileOperationExecutionStarted { operation: FileOperationKind, source: PathBuf, target: PathBuf, action_count: usize, }, FileOperationActionAdvanced { operation: FileOperationKind, source: PathBuf, target: PathBuf, }, FileOperationFinished { operation: FileOperationKind, source: PathBuf, target: PathBuf, summary: FileOperationSummary, dry_run: bool, }, FileApplied { operation: FileOperationKind, source: PathBuf, target: PathBuf, }, FileWouldApply { operation: FileOperationKind, source: PathBuf, target: PathBuf, }, FileMetadataApplied { source: PathBuf, target: PathBuf, }, FileMetadataWouldApply { source: PathBuf, target: PathBuf, }, FileSkipped { operation: FileOperationKind, target: PathBuf, reason: String, }, FileWouldSkip { operation: FileOperationKind, target: PathBuf, reason: String, }, FileDeleted { path: PathBuf, }, FileWouldDelete { path: PathBuf, }, FileWarning { path: PathBuf, reason: String, }, OwnershipWarning { path: PathBuf, reason: String, }, CommandStarted { label: String, }, CommandWouldRun { label: String, }, CommandAllowedFailure { label: String, reason: String, }, InitCreated { path: PathBuf, },
}
A structured message produced during a treeboot operation.

Variants



IgnoredInitScript

A non-executable script candidate was ignored.

Fields

path: PathBuf

Script candidate path.



WouldRunInitScript

A dry run would execute the given init script.

Fields

path: PathBuf

Script path.

root_path: PathBuf

Root checkout path passed as the script argument.



RunInitScript

An init script is about to run.

Fields

path: PathBuf

Script path.



NoConfigDetected

No script or config was found.



RootWorktreeDetected

The run started from the root checkout instead of a separate worktree.



ConfigDetected

A config file was found.

Fields

path: PathBuf

Config file path.



FileOperationPlanningStarted

Planning started for a top-level file operation.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileOperationPlanningFinished

Planning finished for a top-level file operation.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.

action_count: usize

Number of progress-visible actions in the operation.



FileOperationExecutionStarted

Execution started for a top-level file operation.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.

action_count: usize

Number of progress-visible actions in the operation.



FileOperationActionAdvanced

One concrete file-operation action completed.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileOperationFinished

A top-level file operation finished.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.

summary: FileOperationSummary

Compact counts for the operation.

dry_run: bool

Whether the operation was a dry run.



FileApplied

A file operation was applied.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileWouldApply

A dry run would apply a file operation.

Fields

operation: FileOperationKind

File operation kind.

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileMetadataApplied

A sync operation applied metadata-only changes.

Fields

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileMetadataWouldApply

A dry run would apply metadata-only sync changes.

Fields

source: PathBuf

Display source path.

target: PathBuf

Display target path.



FileSkipped

A file operation was skipped.

Fields

operation: FileOperationKind

File operation kind.

target: PathBuf

Display target path.

reason: String

Reason the operation was skipped.



FileWouldSkip

A dry run would skip a file operation.

Fields

operation: FileOperationKind

File operation kind.

target: PathBuf

Display target path.

reason: String

Reason the operation would be skipped.



FileDeleted

A sync operation deleted a target-only path.

Fields

path: PathBuf

Deleted path.



FileWouldDelete

A dry-run sync operation would delete a target-only path.

Fields

path: PathBuf

Path that would be deleted.



FileWarning

A file operation warning was produced.

Fields

path: PathBuf

Warning path.

reason: String

Human-readable warning detail.



OwnershipWarning

Ownership metadata could not be preserved.

Fields

path: PathBuf

Warning path.

reason: String

Human-readable warning detail.



CommandStarted

A command is about to run.

Fields

label: String

Human-readable command label.



CommandWouldRun

A dry run would execute a command.

Fields

label: String

Human-readable command label.



CommandAllowedFailure

A command failure was allowed and execution will continue.

Fields

label: String

Human-readable command label.

reason: String

Failure detail.



InitCreated

An init file was created.

Fields

path: PathBuf

Created file path.

Implementations

Source

impl OutputEvent

pub fn message(&self) -> String

Formats the event as a user-facing line.

Structured lifecycle events used only to drive presentation state return an empty string because they do not have a durable text-line form.