pub enum PlannedFileStatus {
Ready,
SkippedMissingSource,
}Expand description
Execution status for a planned file operation.
Variants
Ready
The operation has an existing source and should run.
SkippedMissingSource
The operation has an optional missing source and should be skipped.