pub fn inspect_config(options: ConfigOptions) -> Result<ConfigReport>Expand description
Parses, normalizes, and returns the selected config file.
Errors
Returns an error if context discovery fails, no config exists, the requested config path does not exist, the config cannot be read, or TOML parsing and normalization fails.