pub struct Executor { /* private fields */ }Expand description
Executes validated action plans.
Implementations
Sourceimpl Executor
impl Executor
Sourcepub const fn new(options: ExecuteOptions) -> Self
pub const fn new(options: ExecuteOptions) -> Self
Creates an executor from execution options.
Sourcepub fn execute_files(
&self,
plan: &ActionPlan,
reporter: &mut dyn Reporter,
) -> Result<ExecutionReport>
pub fn execute_files( &self, plan: &ActionPlan, reporter: &mut dyn Reporter, ) -> Result<ExecutionReport>
Applies the file-operation portion of a plan.
Errors
Returns an error if file operation application or output reporting fails.
Sourcepub fn execute_commands(
&self,
plan: &ActionPlan,
reporter: &mut dyn Reporter,
) -> Result<()>
pub fn execute_commands( &self, plan: &ActionPlan, reporter: &mut dyn Reporter, ) -> Result<()>
Executes the command portion of a plan.
Errors
Returns an error if command execution or output reporting fails.
Sourcepub fn execute(
&self,
plan: &ActionPlan,
reporter: &mut dyn Reporter,
) -> Result<ExecutionReport>
pub fn execute( &self, plan: &ActionPlan, reporter: &mut dyn Reporter, ) -> Result<ExecutionReport>
Executes a complete action plan.
Errors
Returns an error if file operation application, command execution, or output reporting fails.