pub struct RuntimePolicy { /* private fields */ }Expand description
Runtime policy resolved from environment and CLI input.
Implementations
Sourceimpl RuntimePolicy
impl RuntimePolicy
Sourcepub fn from_environment(
environment: &EnvironmentInput,
cli_strict: bool,
) -> Result<Self>
pub fn from_environment( environment: &EnvironmentInput, cli_strict: bool, ) -> Result<Self>
Parses runtime policy from explicit environment input and CLI strictness.
Errors
Returns an error when an environment value is not a supported boolean.
Sourcepub fn from_process_env(cli_strict: bool) -> Result<Self>
pub fn from_process_env(cli_strict: bool) -> Result<Self>
Reads runtime policy from the process environment and CLI strictness.
Errors
Returns an error when an environment value is not a supported boolean.
Sourcepub const fn from_overrides(
overrides: RuntimeOptionOverrides,
cli_strict: bool,
) -> Self
pub const fn from_overrides( overrides: RuntimeOptionOverrides, cli_strict: bool, ) -> Self
Builds runtime policy from parsed environment overrides.
Sourcepub const fn pre_config_strict(&self) -> bool
pub const fn pre_config_strict(&self) -> bool
Returns strict mode before config discovery.
Sourcepub fn resolve(&self, config: &ConfigRuntimeOptions) -> ResolvedRuntimePolicy
pub fn resolve(&self, config: &ConfigRuntimeOptions) -> ResolvedRuntimePolicy
Resolves runtime options using defaults, config, environment, then CLI.