pub enum OutputEvent {
Show 17 variants
IgnoredInitScript {
path: PathBuf,
},
WouldRunInitScript {
path: PathBuf,
root_path: PathBuf,
},
RunInitScript {
path: PathBuf,
},
NoConfigDetected,
RootWorktreeDetected,
ConfigDetected {
path: PathBuf,
},
FileApplied {
operation: FileOperationKind,
source: PathBuf,
target: PathBuf,
},
FileWouldApply {
operation: FileOperationKind,
source: PathBuf,
target: PathBuf,
},
FileSkipped {
operation: FileOperationKind,
target: PathBuf,
reason: String,
},
FileWouldSkip {
operation: FileOperationKind,
target: PathBuf,
reason: String,
},
FileDeleted {
path: PathBuf,
},
FileWouldDelete {
path: PathBuf,
},
FileWarning {
path: PathBuf,
reason: String,
},
CommandStarted {
label: String,
},
CommandWouldRun {
label: String,
},
CommandAllowedFailure {
label: String,
reason: String,
},
InitCreated {
path: PathBuf,
},
}Expand description
A structured message produced during a treeboot operation.
Variants
IgnoredInitScript
A non-executable script candidate was ignored.
WouldRunInitScript
A dry run would execute the given init script.
Fields
RunInitScript
An init script is about to run.
NoConfigDetected
No script or config was found.
RootWorktreeDetected
The run started from the root checkout instead of a separate worktree.
ConfigDetected
A config file was found.
FileApplied
A file operation was applied.
Fields
operation: FileOperationKindFile operation kind.
FileWouldApply
A dry run would apply a file operation.
Fields
operation: FileOperationKindFile operation kind.
FileSkipped
A file operation was skipped.
Fields
operation: FileOperationKindFile operation kind.
FileWouldSkip
A dry run would skip a file operation.
Fields
operation: FileOperationKindFile operation kind.
FileDeleted
A sync operation deleted a target-only path.
FileWouldDelete
A dry-run sync operation would delete a target-only path.
FileWarning
A file operation warning was produced.
CommandStarted
A command is about to run.
CommandWouldRun
A dry run would execute a command.
CommandAllowedFailure
A command failure was allowed and execution will continue.
InitCreated
An init file was created.
Implementations