check

Function check 

pub fn check(options: CheckOptions) -> Result<CheckReport>
Checks treeboot bootstrap behavior without side effects.

Errors

Returns an error when context discovery fails, strict mode treats the current state as invalid, config loading fails, or declarative validation fails.